# With UsrMove (F-17, RHEL-7 onwards), we want the library installed to %%{_libdir} rather than /%%{_lib}
%global UsrMove %([ 0%{?fedora} -gt 16 -o 0%{?rhel} -gt 6 ] && echo 1 || echo 0)

Summary:	A filesystem driver for WebDAV
Name:		davfs2
Version:	1.4.7
Release:	3.0.cf%{?dist}
License:	GPLv2+
Group:		System Environment/Base
URL:		http://savannah.nongnu.org/projects/davfs2
Source0:	http://savannah.nongnu.org/download/davfs2/davfs2-%{version}.tar.gz
Patch0:		davfs2-1.4.7-utf8.patch
Patch1:		davfs2-1.4.7-neon-0.30.patch
Patch2:		davfs2-1.4.7-system.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildRequires:	neon-devel >= 0.25, gettext, symlinks
Requires(pre):	/usr/bin/getent /usr/sbin/groupadd /usr/sbin/useradd
Requires:	fuse
%if %{UsrMove}
Conflicts:	filesystem < 3
%endif
Obsoletes:	fuse-davfs2 < %{version}-%{release}
Provides:	fuse-davfs2 = %{version}-%{release}

%description
davfs2 is a FUSE file system driver that allows you to mount a WebDAV server
as a local file system, like a disk drive. This way applications can access
resources on a Web server without knowing anything about HTTP or WebDAV.

davfs2 runs as a daemon in userspace. It uses the kernel file system coda or
fuse. Most probably your Linux kernel includes at least one of these file
systems.

%prep
%setup -n davfs2-%{version} -q

# Recode German and Spanish manpages as UTF-8
%patch0

# Add support for neon 0.30
%patch1

# CVE-2013-4362: "Unsecure use of system()"
%patch2 -p1

# Don't try to run autotools after patching
touch aclocal.m4
touch config.h.in
touch Makefile.in
touch configure

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%configure \
%if %{UsrMove}
	ssbindir=%{_sbindir} \
%endif
	%{nil}
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot} INSTALL="install -p"

# Add symlinks for mount and umount commands in /sbin where mount will expect to find them
%if ! %{UsrMove}
ln -s -f %{buildroot}%{_sbindir}/mount.davfs %{buildroot}/sbin/mount.davfs
ln -s -f %{buildroot}%{_sbindir}/umount.davfs %{buildroot}/sbin/umount.davfs
symlinks -cs %{buildroot}/sbin
%endif

# Create home directory for the davfs2 account
mkdir -p %{buildroot}%{_localstatedir}/cache/davfs2

# Create directory for PID files
mkdir -p %{buildroot}%{_localstatedir}/run/mount.davfs

# We'll package docs ourselves
rm -rf %{buildroot}%{_docdir}

# Remove suid bit, to work around a problem with brp-strip on suid binaries
# (re-added in %%files section)
chmod 0755 %{buildroot}%{_sbindir}/mount.davfs

%find_lang davfs2

%clean
rm -rf %{buildroot}

%pre
# Create group that normal users must be a member of to use mount.davfs
/usr/bin/getent group davfs2 >/dev/null || /usr/sbin/groupadd -r davfs2

# Create user that mount.davfs will run as when invoked by root
/usr/bin/getent passwd davfs2 >/dev/null || \
	/usr/sbin/useradd -r -s /sbin/nologin -g davfs2 \
		-d %{_localstatedir}/cache/davfs2 \
		-c "WebDAV user id for root" davfs2
exit 0

%files -f davfs2.lang
%doc AUTHORS BUGS COPYING ChangeLog FAQ NEWS README* THANKS TODO
%doc %{_mandir}/man5/davfs2.conf.5*
%doc %{_mandir}/man8/mount.davfs.8*
%doc %{_mandir}/man8/umount.davfs.8*
%doc %{_mandir}/de/man5/davfs2.conf.5*
%doc %{_mandir}/de/man8/mount.davfs.8*
%doc %{_mandir}/de/man8/umount.davfs.8*
%doc %{_mandir}/es/man5/davfs2.conf.5*
%config(noreplace) %{_sysconfdir}/davfs2/davfs2.conf
%config(noreplace) %{_sysconfdir}/davfs2/secrets
%dir %{_sysconfdir}/davfs2/
%dir %{_sysconfdir}/davfs2/certs/
%dir %{_sysconfdir}/davfs2/certs/private/
%if ! %{UsrMove}
/sbin/mount.davfs
/sbin/umount.davfs
%endif
%attr (4755,root,root) %{_sbindir}/mount.davfs
%{_sbindir}/umount.davfs
%dir %attr(0775,davfs2,davfs2) %{_localstatedir}/cache/davfs2/
%dir %attr(01775,root,davfs2)  %{_localstatedir}/run/mount.davfs/
%{_datadir}/davfs2/

%changelog
* Fri Sep 20 2013 Paul Howarth <paul@city-fan.org> - 1.4.7-3.0.cf
- CVE-2013-4362: Fix possibly insecure use of system()

* Fri Sep 13 2013 Paul Howarth <paul@city-fan.org> - 1.4.7-2.0.cf
- Add support for building with neon 0.30
- Don't try to use unsupported configure --disable-static option
- Use -fno-strict-aliasing

* Fri Jul 20 2012 Paul Howarth <paul@city-fan.org> - 1.4.7-1.0.cf
- Update to 1.4.7
  - Search fstab additionally for mount point with trailing slash (Debian
    Bug #580227)
  - Fix various format-string issues
  - Remove check for someone else's home directory (SR #107641)
  - Check return values of system calls
  - Remove fixed length buffer, parse config line in place (Bug #33412)
  - Check for all but temporary errors on USERINFO
  - Fix integer overflow in cache code
  - Fix string comparison in cache code (Bug #33644)
  - Fix client certificate reading issue
  - Translate HTTP 405 into ENOENT (http://savannah.nongnu.org/support/?107869)
  - Quote mpoint in umount_command
  - Get auxiliary groups with getgroups.
- Update UTF-8 patch

* Mon Apr  2 2012 Paul Howarth <paul@city-fan.org> - 1.4.6-3.0.cf
- For F-17/RHEL-7 onwards, install under /usr and conflict with filesystem < 3
  (https://fedoraproject.org/wiki/Features/UsrMove)
- Nobody else likes macros for commands
- Drop %%defattr, redundant since rpm 4.4
- Use a patch rather than scripted iconv to fix manpage encodings
- Maintain timestamps from upstream release where possible

* Tue May  4 2010 Paul Howarth <paul@city-fan.org> - 1.4.6-1.0.cf
- Update to 1.4.6
  - add missing sys/stat.h (bug #28916)
  - fix wrong assignment of password from pam_mount (bug #28706)
- Drop upstreamed davfs2-1.4.5-sys_stat_h.patch
- Tidy up %%description

* Tue Feb 16 2010 Paul Howarth <paul@city-fan.org> - 1.4.5-2.0.cf
- Add davfs2-1.4.5-sys_stat_h.patch to fix building on F-13

* Mon Nov 16 2009 Paul Howarth <paul@city-fan.org> - 1.4.5-1.0.cf
- Update to 1.4.5 (don't prompt about unverified certificates if "askauth 0")

* Mon Oct 19 2009 Paul Howarth <paul@city-fan.org> - 1.4.3-1.0.cf
- Update to 1.4.3
  - support for NTLM authentication (with Neon 0.29 only)
  - change to option askauth behaviour for non-trusted certificates
  - various bugfixes (see ChangeLog)
- Requires: fuse
- Don't use a specific mirror for the source0 URL
- Don't self-obsolete

* Fri Jul 10 2009 Paul Howarth <paul@city-fan.org> - 1.4.1-2.0.cf
- Don't remove %%{_datadir}/davfs2 from package - mount.davfs copies config
  files from there to ~/.davfs2 if there aren't any present already
- Don't ship davfs2.conf and secrets as %%doc (already included in /etc)

* Mon Jun 15 2009 Paul Howarth <paul@city-fan.org> - 1.4.1-1.0.cf
- Update to 1.4.1 (retry uploads on connection failures)
- Include files patch for 1.4.0 now upstream

* Fri May  8 2009 Paul Howarth <paul@city-fan.org> - 1.4.0-1.0.cf
- Update to 1.4.0 (see NEWS for details of signficant config changes)
- Upstream moved to Savannah, fix URLs
- 2-arg open() problem fixed upstream, remove patch
- cache.c needs stdlib.h, apply patch to fix builds on some older platforms
- Add version (>= 0.25) requirement for neon-devel

* Fri Mar 20 2009 Paul Howarth <paul@city-fan.org> - 1.3.3-2.0.cf
- Rename to davfs2 as per the recently-imported version in Fedora
- Provide/Obsolete fuse-davfs2 for upgrade path
- Change group to System Environment/Base
- Include directory %%{_localstatedir}/run/mount.davfs for PID files
- Add symlinks for mount/umount commands in /sbin rather than moving them from
  %%{_sbindir} to /sbin
- Remove %%{_datadir}/davfs2, duplicate of %%{_sysconfdir}/davfs2
- Ensure that %%pre scriptlet always exits successfully
- Add group write permission for directory %%{_localstatedir}/cache/davfs2/
- Don't actually need buildreq fuse-devel, or fuse dependency

* Tue Feb 17 2009 Paul Howarth <paul@city-fan.org> - 1.3.3-1.cf
- Import from RPMforge
- Update to 1.3.3
- Create user and group davfs2 in %%pre
- License is GPL version 2 or later
- Recode German and Spanish manpages as UTF-8
- Add dist tag

* Sat Nov 10 2007 Dag Wieers <dag@wieers.com> - 1.2.2-1 - 5397+/dag
- Updated to release 1.2.2.

* Sat May 12 2007 Dag Wieers <dag@wieers.com> - 1.2.1-1
- Initial package. (using DAR)
